@@ -648,8 +648,14 @@ class AwsLimitChecker(object):
         :rtype: dict
         """
         required_actions = [
+            'cloudwatch:GetMetricData',
             'servicequotas:ListServiceQuotas',
-            'support:*',
+            'support:DescribeTrustedAdvisorCheckRefreshStatuses',
+            'support:DescribeTrustedAdvisorCheckResult',
+            'support:DescribeTrustedAdvisorCheckSummaries',
+            'support:DescribeTrustedAdvisorChecks',
+            'support:RefreshTrustedAdvisorCheck',
+            'sts:GetCallerIdentity',
             'trustedadvisor:Describe*',
             'trustedadvisor:RefreshCheck'
         ]
