@@ -81,7 +81,9 @@ class _VpcService(_AwsService):
     def _find_usage_vpcs(self):
         """find usage for VPCs"""
         # overall number of VPCs
-        vpcs = self.conn.describe_vpcs()
+        vpcs = self.conn.describe_vpcs(
+            Filters=[{'Name': 'owner-id', 'Values': [self.current_account_id]}]
+        )
         self.limits['VPCs']._add_current_usage(
             len(vpcs['Vpcs']),
             aws_type='AWS::EC2::VPC'
@@ -92,7 +94,9 @@ class _VpcService(_AwsService):
         # subnets per VPC
         subnet_to_az = {}
         subnets = defaultdict(int)
-        for subnet in self.conn.describe_subnets()['Subnets']:
+        for subnet in self.conn.describe_subnets(
+            Filters=[{'Name': 'owner-id', 'Values': [self.current_account_id]}]
+        )['Subnets']:
             subnets[subnet['VpcId']] += 1
             subnet_to_az[subnet['SubnetId']] = subnet['AvailabilityZone']
         for vpc_id in subnets:
@@ -107,7 +111,9 @@ class _VpcService(_AwsService):
         """find usage for ACLs"""
         # Network ACLs per VPC
         acls = defaultdict(int)
-        for acl in self.conn.describe_network_acls()['NetworkAcls']:
+        for acl in self.conn.describe_network_acls(
+            Filters=[{'Name': 'owner-id', 'Values': [self.current_account_id]}]
+        )['NetworkAcls']:
             acls[acl['VpcId']] += 1
             # Rules per network ACL
             self.limits['Rules per network ACL']._add_current_usage(
@@ -126,7 +132,9 @@ class _VpcService(_AwsService):
         """find usage for route tables"""
         # Route tables per VPC
         tables = defaultdict(int)
-        for table in self.conn.describe_route_tables()['RouteTables']:
+        for table in self.conn.describe_route_tables(
+            Filters=[{'Name': 'owner-id', 'Values': [self.current_account_id]}]
+        )['RouteTables']:
             tables[table['VpcId']] += 1
             # Entries per route table
             routes = [
@@ -148,7 +156,9 @@ class _VpcService(_AwsService):
     def _find_usage_gateways(self):
         """find usage for Internet Gateways"""
         # Internet gateways
-        gws = self.conn.describe_internet_gateways()
+        gws = self.conn.describe_internet_gateways(
+            Filters=[{'Name': 'owner-id', 'Values': [self.current_account_id]}]
+        )
         self.limits['Internet gateways']._add_current_usage(
             len(gws['InternetGateways']),
             aws_type='AWS::EC2::InternetGateway',
@@ -166,11 +176,11 @@ class _VpcService(_AwsService):
         # "This request has been administratively disabled."
         try:
             gws_per_az = defaultdict(int)
-            for gw in paginate_dict(self.conn.describe_nat_gateways,
-                                    alc_marker_path=['NextToken'],
-                                    alc_data_path=['NatGateways'],
-                                    alc_marker_param='NextToken'
-                                    )['NatGateways']:
+            for gw in paginate_dict(
+                self.conn.describe_nat_gateways,
+                alc_marker_path=['NextToken'], alc_data_path=['NatGateways'],
+                alc_marker_param='NextToken'
+            )['NatGateways']:
                 if gw['State'] not in ['pending', 'available']:
                     logger.debug(
                         'Skipping NAT Gateway %s in state: %s',
@@ -220,7 +230,8 @@ class _VpcService(_AwsService):
             self.conn.describe_network_interfaces,
             alc_marker_path=['NextToken'],
             alc_data_path=['NetworkInterfaces'],
-            alc_marker_param='NextToken'
+            alc_marker_param='NextToken',
+            Filters=[{'Name': 'owner-id', 'Values': [self.current_account_id]}]
         )
 
         self.limits['Network interfaces per Region']._add_current_usage(
@@ -317,6 +328,7 @@ class _VpcService(_AwsService):
             self.warning_threshold,
             self.critical_threshold,
             limit_type='AWS::EC2::NatGateway',
+            quotas_name='NAT gateways per Availability Zone'
         )
 
         limits['Virtual private gateways'] = AwsLimit(
